==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningCategoryStyleEventArgsBaseDescriptionMetadata } from "./AssigningCategoryStyleEventArgsBaseDescriptionMetadata";
import { AssigningCategoryMarkerStyleEventArgsDescription } from "./AssigningCategoryMarkerStyleEventArgsDescription";
/**
 * @hidden
 */
var AssigningCategoryMarkerStyleEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AssigningCategoryMarkerStyleEventArgsDescriptionMetadata, _super);
    function AssigningCategoryMarkerStyleEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.b = function (a) {
        if (AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a == null) {
            AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.c(AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a);
        }
        if (a.k(AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a);
    };
    AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.c = function (a) {
        AssigningCategoryStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.d = function (a) {
        AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.b(a);
        a.ad("AssigningCategoryMarkerStyleEventArgs", function () { return new AssigningCategoryMarkerStyleEventArgsDescription(); });
        a.ac("AssigningCategoryMarkerStyleEventArgs", AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a);
    };
    AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.$t = markType(AssigningCategoryMarkerStyleEventArgsDescriptionMetadata, 'AssigningCategoryMarkerStyleEventArgsDescriptionMetadata');
    AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a = null;
    return AssigningCategoryMarkerStyleEventArgsDescriptionMetadata;
}(Base));
export { AssigningCategoryMarkerStyleEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningCategoryStyleEventArgsBaseDescriptionMetadata } from "./AssigningCategoryStyleEventArgsBaseDescriptionMetadata";
import { AssigningCategoryMarkerStyleEventArgsDescription } from "./AssigningCategoryMarkerStyleEventArgsDescription";
/**
 * @hidden
 */
var AssigningCategoryMarkerStyleEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AssigningCategoryMarkerStyleEventArgsDescriptionMetadata, _super);
    function AssigningCategoryMarkerStyleEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.b = function (a) {
        if (AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a == null) {
            AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.c(AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a);
        }
        if (a.k(AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a);
    };
    AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.c = function (a) {
        AssigningCategoryStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.d = function (a) {
        AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.b(a);
        a.ae("AssigningCategoryMarkerStyleEventArgs", function () { return new AssigningCategoryMarkerStyleEventArgsDescription(); });
        a.ad("AssigningCategoryMarkerStyleEventArgs", AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a);
    };
    AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.$t = markType(AssigningCategoryMarkerStyleEventArgsDescriptionMetadata, 'AssigningCategoryMarkerStyleEventArgsDescriptionMetadata');
    AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.a = null;
    return AssigningCategoryMarkerStyleEventArgsDescriptionMetadata;
}(Base));
export { AssigningCategoryMarkerStyleEventArgsDescriptionMetadata };
